Reference
=========

.. currentmodule:: gql

.. _top-level-functions:

Top-Level Functions
-------------------

.. automodule:: gql

.. _sub-packages:

Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   client
   transport
   dsl
